@@ -46,14 +46,17 @@ def run_airflow_task(source: Optional[str], task: TaskInterface, **context):
     dag_context = make_typhoon_dag_context(context)
     if source is not None:
         session = settings.Session()
-        batches = {
-            x.key: x.value for x in
-            session.query(XCom).filter(
-                XCom.task_id == source,
-                XCom.dag_id == context['dag'].dag_id,
-                XCom.execution_date == dag_context.execution_time,
-            ).order_by(XCom.key)
-        }
+        try:
+            batches = {
+                x.key: x.value for x in
+                session.query(XCom).filter(
+                    XCom.task_id == source,
+                    XCom.dag_id == context['dag'].dag_id,
+                    XCom.execution_date == dag_context.execution_time,
+                ).order_by(XCom.key)
+            }
+        finally:
+            session.close()
         batch_groups = {}
         # They are sorted by XCom key so no need to worry about order
         for key, batch_and_batch_num in batches.items():
